@@ -9,7 +9,7 @@ class ParseCappReport(HTMLParser.HTMLParser):
     def handle_data(self, data):
         self.data_stack.append(data)
 
-def parseCourses(html):
+def getCoursesTaken(html):
     parser = ParseCappReport()
     html_text = parser.feed(html).data_stack
     courses = []
